@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2008-2010 Jens Vagelpohl and Contributors. All Rights Reserved.
+# Copyright (c) 2008-2012 Jens Vagelpohl and Contributors. All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
@@ -11,8 +11,6 @@
 #
 ##############################################################################
 """ dataflake.ldapconnnection interfaces
-
-$Id: interfaces.py 1889 2010-02-02 21:55:08Z jens $
 """
 
 from zope.interface import Interface
@@ -76,6 +74,10 @@ class ILDAPConnection(Interface):
         thrown by the last attempted connection is re-raised.
         """
 
+    def disconnect():
+        """ Close the current LDAP server connection
+        """
+
     def search( base
               , scope=2
               , fltr='(objectClass=*)'
@@ -83,6 +85,7 @@ class ILDAPConnection(Interface):
               , convert_filter=True
               , bind_dn=None
               , bind_pwd=None
+              , raw=False
               ):
         """ Perform a LDAP search
 
@@ -93,7 +96,7 @@ class ILDAPConnection(Interface):
         What to search for is described by the `filter` argument, which 
         must be a valid LDAP search filter string. If only certain record 
         attributes should be returned, they can be specified in the `attrs` 
-        sequence.
+        sequence. If `raw` is true, results are returned in the ldap_encoding.
 
         If the search raised no errors, a mapping with the following keys
         is returned:
