@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2008-2010 Jens Vagelpohl and Contributors. All Rights Reserved.
+# Copyright (c) 2008-2012 Jens Vagelpohl and Contributors. All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
@@ -11,8 +11,6 @@
 #
 ##############################################################################
 """ test_connection_basic: Basic tests for the LDAPConnection class
-
-$Id: test_connection_basic.py 1895 2010-02-04 21:09:28Z jens $
 """
 
 import unittest
@@ -37,7 +35,8 @@ class ConnectionBasicTests(LDAPConnectionTests):
 
     def test_constructor_defaults(self):
         conn = self._makeSimple()
-        self.assertEqual(conn.bind_dn, u'')
+        self.assertTrue(isinstance(conn.bind_dn, str))
+        self.assertEqual(conn.bind_dn, '')
         self.assertEqual(conn.bind_pwd, '')
         self.failIf(conn.read_only)
         self.assertEqual(conn._getConnection(), None)
@@ -45,7 +44,6 @@ class ConnectionBasicTests(LDAPConnectionTests):
 
     def test_constructor(self):
         bind_dn_encoded = 'cn=%s,dc=localhost' % ISO_8859_1_ENCODED
-        bind_dn_unicode = u'cn=%s,dc=localhost' % ISO_8859_1_UNICODE
         conn = self._makeOne( 'localhost'
                             , 389
                             , 'ldap'
@@ -57,7 +55,8 @@ class ConnectionBasicTests(LDAPConnectionTests):
                             , op_timeout=10
                             , logger='logger'
                             )
-        self.assertEqual(conn.bind_dn, bind_dn_unicode)
+        self.assertTrue(isinstance(conn.bind_dn, str))
+        self.assertEqual(conn.bind_dn, bind_dn_encoded)
         self.assertEqual(conn.bind_pwd, 'foo')
         self.failUnless(conn.read_only)
         self.assertEqual(conn._getConnection(), None)
@@ -73,6 +72,7 @@ class ConnectionBasicTests(LDAPConnectionTests):
                             , bind_dn=bind_dn_unicode
                             , bind_pwd='foo'
                             )
+        self.assertTrue(isinstance(conn.bind_dn, unicode))
         self.assertEqual(conn.bind_dn, bind_dn_unicode)
 
     def test_encode_incoming(self):
