@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2008-2010 Jens Vagelpohl and Contributors. All Rights Reserved.
+# Copyright (c) 2008-2012 Jens Vagelpohl and Contributors. All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
@@ -11,8 +11,6 @@
 #
 ##############################################################################
 """ test_connection_connect: Tests for the LDAPConnection connect method
-
-$Id: test_connection_connect.py 1901 2010-02-07 19:01:08Z jens $
 """
 
 import unittest
@@ -28,7 +26,8 @@ class ConnectionConnectTests(LDAPConnectionTests):
         conn = self._makeSimple()
         connection = conn.connect()
         binduid, bindpwd = connection._last_bind[1]
-        self.assertEqual(binduid, u'')
+        self.assertTrue(isinstance(binduid, str))
+        self.assertEqual(binduid, '')
         self.assertEqual(bindpwd, '')
         self.failIf(getattr(connection, 'timeout', False))
         self.assertEquals( connection.options.get(ldap.OPT_REFERRALS)
@@ -93,6 +92,70 @@ class ConnectionConnectTests(LDAPConnectionTests):
         connection = conn.connect()
         self.failIf(connection.options.has_key(ldap.OPT_REFERRALS))
 
+    def test_disconnect_clears_connection_cache(self):
+        from dataflake.ldapconnection.tests import fakeldap
+        conn = self._makeSimple()
+
+        attrs = {'userPassword': fakeldap.hash_pwd('pass')}
+        conn.insert('dc=localhost', 'cn=foo', attrs=attrs)
+
+        response = conn.search( 'dc=localhost'
+                              , fltr='(cn=foo)'
+                              , bind_dn='cn=foo,dc=localhost'
+                              , bind_pwd='pass'
+                              )
+        self.assertEquals(response['size'], 1)
+
+        connection = conn._getConnection()
+        self.assertNotEquals(connection, None)
+        self.assertEquals(connection._last_bind[1], ('cn=foo,dc=localhost', 'pass'))
+
+        conn.disconnect()
+        self.assertEquals(conn._getConnection(), None)
+
+    def test_disconnect_unbinds_connection(self):
+        from dataflake.ldapconnection.tests import fakeldap
+        conn = self._makeSimple()
+
+        attrs = {'userPassword': fakeldap.hash_pwd('pass')}
+        conn.insert('dc=localhost', 'cn=foo', attrs=attrs)
+
+        response = conn.search( 'dc=localhost'
+                              , fltr='(cn=foo)'
+                              , bind_dn='cn=foo,dc=localhost'
+                              , bind_pwd='pass'
+                              )
+        self.assertEquals(response['size'], 1)
+
+        connection = conn._getConnection()
+        self.assertNotEquals(connection, None)
+        self.assertEquals(connection._last_bind[1], ('cn=foo,dc=localhost', 'pass'))
+
+        conn.disconnect()
+        self.assertEquals(connection._last_bind, None)
+
+    def test_rebind_with_same_password(self):
+        from dataflake.ldapconnection.tests import fakeldap
+        conn = self._makeSimple()
+
+        attrs = {'userPassword': fakeldap.hash_pwd('pass')}
+        conn.insert( 'dc=localhost'
+                   , 'cn=foo'
+                   , attrs=attrs
+                   , bind_dn='cn=Manager,dc=localhost'
+                   , bind_pwd='pass'
+                   )
+        connection = conn._getConnection()
+        self.assertEqual(connection._last_bind[1], ('cn=Manager,dc=localhost', 'pass'))
+
+        conn.search( 'dc=localhost'
+                   , fltr='(cn=foo)'
+                   , bind_dn='cn=foo,dc=localhost'
+                   , bind_pwd='pass'
+                   )
+        connection = conn._getConnection()
+        self.assertEqual(connection._last_bind[1], ('cn=foo,dc=localhost', 'pass'))
+
 
 def test_suite():
     import sys
